@@ -4,44 +4,70 @@ build_time_vars = {'ABIFLAGS': 'm',
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': '@echo hg: no-repository, python: found! cannot run ./Parser/asdl_c.py # ./Parser/asdl_c.py',
- 'ASDLGEN_FILES': './Parser/asdl.py ./Parser/asdl_c.py',
- 'AST_ASDL': './Parser/Python.asdl',
- 'AST_C': './Python/Python-ast.c',
- 'AST_C_DIR': './Python',
- 'AST_H': './Include/Python-ast.h',
- 'AST_H_DIR': './Include',
- 'BASECFLAGS': '-fno-strict-aliasing',
+ 'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
+ 'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/python-inst/bin',
- 'BINLIBDEST': '/python-inst/lib/python3.3',
- 'BLDLIBRARY': '-L. -lpython3.3m',
- 'BLDSHARED': 'gcc -I/home/baseline/core/solver/unxlngi6.pro/inc/external -I/home/baseline/core/solver/unxlngi6.pro/inc/external/expat -pthread -shared -L/home/baseline/core/solver/unxlngi6.pro/lib -L/home/baseline/core/solver/unxlngi6.pro/lib',
+ 'BINLIBDEST': '/python-inst/lib/python3.5',
+ 'BLDLIBRARY': '-L. -lpython3.5m',
+ 'BLDSHARED': '/usr/bin/ccache /opt/rh/devtoolset-2/root/usr/bin/gcc '
+              '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
+              '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
+              '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
+              '-pthread -shared '
+              '-L/home/buildslave/build/workdir/UnpackedTarball/openssl '
+              '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
+ 'BUILD_GNU_TYPE': 'i686-pc-linux-gnu',
  'BYTESTR_DEPS': '\\',
- 'CC': 'gcc -I/home/baseline/core/solver/unxlngi6.pro/inc/external -I/home/baseline/core/solver/unxlngi6.pro/inc/external/expat -pthread',
+ 'CC': '/usr/bin/ccache /opt/rh/devtoolset-2/root/usr/bin/gcc '
+       '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
+       '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
+       '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -DNDEBUG  -O0 -Wall -Wstrict-prototypes',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 -Wall '
+           '-Wstrict-prototypes',
  'CFLAGSFORSHARED': '-fPIC',
- 'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
+ 'CFLAGS_ALIASING': '',
+ 'CFLAGS_NODIST': '',
+ 'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
+                'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
+ 'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '-L/home/baseline/core/solver/unxlngi6.pro/lib -L/home/baseline/core/solver/unxlngi6.pro/lib',
- 'CONFIG_ARGS': "'--with-system-expat' '--prefix=/python-inst' '--enable-shared' 'CC=gcc -I/home/baseline/core/solver/unxlngi6.pro/inc/external -I/home/baseline/core/solver/unxlngi6.pro/inc/external/expat' 'LDFLAGS=-L/home/baseline/core/solver/unxlngi6.pro/lib -L/home/baseline/core/solver/unxlngi6.pro/lib'",
+ 'CONFIGURE_LDFLAGS': '-L/home/buildslave/build/workdir/UnpackedTarball/openssl '
+                      '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary',
+ 'CONFIG_ARGS': "'--prefix=/python-inst' '--with-system-expat' "
+                "'--enable-shared' 'CC=/usr/bin/ccache "
+                '/opt/rh/devtoolset-2/root/usr/bin/gcc '
+                '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
+                '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
+                "-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib' "
+                "'CFLAGS= ' "
+                "'LDFLAGS=-L/home/buildslave/build/workdir/UnpackedTarball/openssl "
+                "-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary' "
+                "'PKG_CONFIG=/usr/bin/pkg-config'",
  'CONFINCLUDEDIR': '/python-inst/include',
- 'CONFINCLUDEPY': '/python-inst/include/python3.3m',
+ 'CONFINCLUDEPY': '/python-inst/include/python3.5m',
  'COREPYTHONPATH': ':plat-linux',
+ 'COVERAGE_INFO': '/home/buildslave/build/workdir/UnpackedTarball/python3/coverage.info',
+ 'COVERAGE_REPORT': '/home/buildslave/build/workdir/UnpackedTarball/python3/lcov-report',
+ 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
+                            'report"',
  'CPPFLAGS': '-I. -I./Include',
- 'CXX': 'g++ -pthread',
- 'DESTDIRS': '/python-inst /python-inst/lib /python-inst/lib/python3.3 /python-inst/lib/python3.3/lib-dynload',
- 'DESTLIB': '/python-inst/lib/python3.3',
+ 'CXX': '/usr/bin/ccache /opt/rh/devtoolset-2/root/usr/bin/g++ -pthread',
+ 'DESTDIRS': '/python-inst /python-inst/lib /python-inst/lib/python3.5 '
+             '/python-inst/lib/python3.5/lib-dynload',
+ 'DESTLIB': '/python-inst/lib/python3.5',
  'DESTPATH': '',
- 'DESTSHARED': '/python-inst/lib/python3.3/lib-dynload',
+ 'DESTSHARED': '/python-inst/lib/python3.5/lib-dynload',
  'DIRMODE': 755,
- 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in Include Lib Misc Ext-dummy',
+ 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
+         'Makefile.pre.in Include Lib Misc Ext-dummy',
  'DISTDIRS': 'Include Lib Misc Ext-dummy',
- 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
+ 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h '
+              'pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
@@ -49,29 +75,31 @@ build_time_vars = {'ABIFLAGS': 'm',
  'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
+ 'ENSUREPIP': 'upgrade',
  'EXE': '',
  'EXEMODE': 755,
  'EXTRAMACHDEPPATH': '',
- 'EXTRAPLATDIR': '@EXTRAPLATDIR@',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
+ 'EXT_SUFFIX': '.cpython-3.5m.so',
  'FILEMODE': 644,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
  'GETTIMEOFDAY_NO_TZ': 0,
+ 'GITBRANCH': '',
+ 'GITTAG': '',
+ 'GITVERSION': '',
  'GNULD': 'yes',
- 'GRAMMAR_C': './Python/graminit.c',
- 'GRAMMAR_H': './Include/graminit.h',
- 'GRAMMAR_INPUT': './Grammar/Grammar',
- 'HAVE_ACCEPT4': 0,
+ 'HAVE_ACCEPT4': 1,
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
+ 'HAVE_ALIGNED_REQUIRED': 0,
+ 'HAVE_ALLOCA_H': 1,
  'HAVE_ALTZONE': 0,
  'HAVE_ASINH': 1,
  'HAVE_ASM_TYPES_H': 1,
  'HAVE_ATANH': 1,
- 'HAVE_ATTRIBUTE_FORMAT_PARSETUPLE': 0,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
  'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
@@ -81,8 +109,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_BROKEN_POLL': 0,
  'HAVE_BROKEN_POSIX_SEMAPHORES': 0,
  'HAVE_BROKEN_PTHREAD_SIGMASK': 0,
- 'HAVE_BROKEN_SEM_GETVALUE': 1,
+ 'HAVE_BROKEN_SEM_GETVALUE': 0,
  'HAVE_BROKEN_UNSETENV': 0,
+ 'HAVE_BUILTIN_ATOMIC': 1,
  'HAVE_C99_BOOL': 1,
  'HAVE_CHFLAGS': 0,
  'HAVE_CHOWN': 1,
@@ -108,14 +137,17 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DEV_PTC': 0,
  'HAVE_DEV_PTMX': 1,
  'HAVE_DIRECT_H': 0,
+ 'HAVE_DIRENT_D_TYPE': 1,
  'HAVE_DIRENT_H': 1,
  'HAVE_DIRFD': 1,
  'HAVE_DLFCN_H': 1,
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
+ 'HAVE_DUP3': 1,
  'HAVE_DYNAMIC_LOADING': 1,
+ 'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 1,
- 'HAVE_EPOLL_CREATE1': 0,
+ 'HAVE_EPOLL_CREATE1': 1,
  'HAVE_ERF': 1,
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
@@ -145,17 +177,18 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_FTELLO': 1,
  'HAVE_FTIME': 1,
  'HAVE_FTRUNCATE': 1,
- 'HAVE_FUTIMENS': 0,
+ 'HAVE_FUTIMENS': 1,
  'HAVE_FUTIMES': 1,
  'HAVE_FUTIMESAT': 1,
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GAMMA': 1,
+ 'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 1,
  'HAVE_GCC_UINT128_T': 0,
  'HAVE_GETADDRINFO': 1,
- 'HAVE_GETCWD': 1,
  'HAVE_GETC_UNLOCKED': 1,
+ 'HAVE_GETENTROPY': 0,
  'HAVE_GETGROUPLIST': 1,
  'HAVE_GETGROUPS': 1,
  'HAVE_GETHOSTBYNAME': 0,
@@ -174,6 +207,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GETPID': 1,
  'HAVE_GETPRIORITY': 1,
  'HAVE_GETPWENT': 1,
+ 'HAVE_GETRANDOM': 0,
+ 'HAVE_GETRANDOM_SYSCALL': 0,
  'HAVE_GETRESGID': 1,
  'HAVE_GETRESUID': 1,
  'HAVE_GETSID': 1,
@@ -184,12 +219,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
  'HAVE_HSTRERROR': 1,
+ 'HAVE_HTOLE64': 1,
  'HAVE_HYPOT': 1,
  'HAVE_IEEEFP_H': 0,
  'HAVE_IF_NAMEINDEX': 1,
  'HAVE_INET_ATON': 1,
  'HAVE_INET_PTON': 1,
  'HAVE_INITGROUPS': 1,
+ 'HAVE_INT32_T': 1,
+ 'HAVE_INT64_T': 1,
  'HAVE_INTTYPES_H': 1,
  'HAVE_IO_H': 0,
  'HAVE_IPA_PURE_CONST_BUG': 0,
@@ -212,9 +250,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LIBUTIL_H': 0,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
- 'HAVE_LINUX_CAN_H': 0,
- 'HAVE_LINUX_CAN_RAW_H': 0,
+ 'HAVE_LINUX_CAN_BCM_H': 0,
+ 'HAVE_LINUX_CAN_H': 1,
+ 'HAVE_LINUX_CAN_RAW_FD_FRAMES': 0,
+ 'HAVE_LINUX_CAN_RAW_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
+ 'HAVE_LINUX_RANDOM_H': 1,
  'HAVE_LINUX_TIPC_H': 1,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
@@ -222,7 +263,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LONG_DOUBLE': 1,
  'HAVE_LONG_LONG': 1,
  'HAVE_LSTAT': 1,
- 'HAVE_LUTIMES': 0,
+ 'HAVE_LUTIMES': 1,
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
  'HAVE_MEMMOVE': 1,
@@ -246,15 +287,17 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_OSX105_SDK': 0,
  'HAVE_PATHCONF': 1,
  'HAVE_PAUSE': 1,
- 'HAVE_PIPE2': 0,
+ 'HAVE_PIPE2': 1,
  'HAVE_PLOCK': 0,
  'HAVE_POLL': 1,
  'HAVE_POLL_H': 1,
  'HAVE_POSIX_FADVISE': 1,
  'HAVE_POSIX_FALLOCATE': 1,
  'HAVE_PREAD': 1,
+ 'HAVE_PRLIMIT': 0,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
+ 'HAVE_PTHREAD_ATFORK': 1,
  'HAVE_PTHREAD_DESTRUCTOR': 0,
  'HAVE_PTHREAD_H': 1,
  'HAVE_PTHREAD_INIT': 0,
@@ -268,6 +311,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
  'HAVE_RENAMEAT': 1,
+ 'HAVE_RL_APPEND_HISTORY': 0,
  'HAVE_RL_CALLBACK': 0,
  'HAVE_RL_CATCH_SIGNAL': 0,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 0,
@@ -275,6 +319,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_RL_COMPLETION_MATCHES': 0,
  'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 0,
  'HAVE_RL_PRE_INPUT_HOOK': 0,
+ 'HAVE_RL_RESIZE_TERMINAL': 0,
  'HAVE_ROUND': 1,
  'HAVE_SCHED_GET_PRIORITY_MAX': 1,
  'HAVE_SCHED_H': 1,
@@ -327,12 +372,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_STDARG_PROTOTYPES': 1,
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
+ 'HAVE_STD_ATOMIC': 0,
  'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
  'HAVE_STRLCPY': 0,
- 'HAVE_STROPTS_H': 1,
+ 'HAVE_STROPTS_H': 0,
  'HAVE_STRUCT_STAT_ST_BIRTHTIME': 0,
  'HAVE_STRUCT_STAT_ST_BLKSIZE': 1,
  'HAVE_STRUCT_STAT_ST_BLOCKS': 1,
@@ -340,7 +386,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_STRUCT_STAT_ST_GEN': 0,
  'HAVE_STRUCT_STAT_ST_RDEV': 1,
  'HAVE_STRUCT_TM_TM_ZONE': 1,
- 'HAVE_ST_BLOCKS': 1,
  'HAVE_SYMLINK': 1,
  'HAVE_SYMLINKAT': 1,
  'HAVE_SYNC': 1,
@@ -350,6 +395,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
+ 'HAVE_SYS_ENDIAN_H': 0,
  'HAVE_SYS_EPOLL_H': 1,
  'HAVE_SYS_EVENT_H': 0,
  'HAVE_SYS_FILE_H': 1,
@@ -362,6 +408,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
  'HAVE_SYS_POLL_H': 1,
+ 'HAVE_SYS_RANDOM_H': 0,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
  'HAVE_SYS_SENDFILE_H': 1,
@@ -394,6 +441,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_TRUNCATE': 1,
  'HAVE_TZNAME': 0,
  'HAVE_UCS4_TCL': 0,
+ 'HAVE_UINT32_T': 1,
+ 'HAVE_UINT64_T': 1,
  'HAVE_UINTPTR_T': 1,
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
@@ -401,7 +450,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_UNSETENV': 1,
  'HAVE_USABLE_WCHAR_T': 0,
  'HAVE_UTIL_H': 0,
- 'HAVE_UTIMENSAT': 0,
+ 'HAVE_UTIMENSAT': 1,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
  'HAVE_WAIT3': 1,
@@ -412,73 +461,105 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_WCSCOLL': 1,
  'HAVE_WCSFTIME': 1,
  'HAVE_WCSXFRM': 1,
+ 'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HGBRANCH': '',
- 'HGTAG': '',
- 'HGVERSION': '',
  'HOST_GNU_TYPE': 'i686-pc-linux-gnu',
- 'INCLDIRSTOMAKE': '/python-inst/include /python-inst/include /python-inst/include/python3.3m /python-inst/include/python3.3m',
+ 'INCLDIRSTOMAKE': '/python-inst/include /python-inst/include '
+                   '/python-inst/include/python3.5m '
+                   '/python-inst/include/python3.5m',
  'INCLUDEDIR': '/python-inst/include',
- 'INCLUDEPY': '/python-inst/include/python3.3m',
+ 'INCLUDEPY': '/python-inst/include/python3.5m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'libpython3.3m.so.1.0',
+ 'INSTSONAME': 'libpython3.5m.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'g++ -pthread -shared',
- 'LDFLAGS': '-L/home/baseline/core/solver/unxlngi6.pro/lib -L/home/baseline/core/solver/unxlngi6.pro/lib',
+ 'LDCXXSHARED': '/usr/bin/ccache /opt/rh/devtoolset-2/root/usr/bin/g++ '
+                '-pthread -shared',
+ 'LDFLAGS': '-L/home/buildslave/build/workdir/UnpackedTarball/openssl '
+            '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython3.3m.so',
+ 'LDLIBRARY': 'libpython3.5m.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -I/home/baseline/core/solver/unxlngi6.pro/inc/external -I/home/baseline/core/solver/unxlngi6.pro/inc/external/expat -pthread -shared -L/home/baseline/core/solver/unxlngi6.pro/lib -L/home/baseline/core/solver/unxlngi6.pro/lib',
- 'LDVERSION': '3.3m',
+ 'LDSHARED': '/usr/bin/ccache /opt/rh/devtoolset-2/root/usr/bin/gcc '
+             '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
+             '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
+             '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
+             '-pthread -shared '
+             '-L/home/buildslave/build/workdir/UnpackedTarball/openssl '
+             '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary',
+ 'LDVERSION': '3.5m',
  'LIBC': '',
- 'LIBDEST': '/python-inst/lib/python3.3',
+ 'LIBDEST': '/python-inst/lib/python3.5',
  'LIBDIR': '/python-inst/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/python-inst/lib/pkgconfig',
- 'LIBPL': '/python-inst/lib/python3.3/config-3.3m',
- 'LIBRARY': 'libpython3.3m.a',
+ 'LIBPL': '/python-inst/lib/python3.5/config-3.5m',
+ 'LIBRARY': 'libpython3.5m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-lpthread -ldl  -lutil',
+ 'LIBS': '-lpthread -ldl  -lutil -lrt',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
- 'LINKCC': 'gcc -I/home/baseline/core/solver/unxlngi6.pro/inc/external -I/home/baseline/core/solver/unxlngi6.pro/inc/external/expat -pthread',
+ 'LINKCC': '/usr/bin/ccache /opt/rh/devtoolset-2/root/usr/bin/gcc '
+           '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
+           '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
+           '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
+           '-pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
+ 'LIPO_32BIT_FLAGS': '',
+ 'LLVM_PROF_ERR': 'no',
+ 'LLVM_PROF_FILE': '',
+ 'LLVM_PROF_MERGER': 'true',
  'LN': 'ln',
  'LOCALMODLIBS': '',
  'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'linux',
  'MACHDEPPATH': ':plat-linux',
- 'MACHDEPS': 'plat-linux @EXTRAPLATDIR@',
+ 'MACHDEPS': 'plat-linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/python-inst/lib/python3.3',
+ 'MACHDESTLIB': '/python-inst/lib/python3.5',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'gcc -I/home/baseline/core/solver/unxlngi6.pro/inc/external -I/home/baseline/core/solver/unxlngi6.pro/inc/external/expat -pthread',
+ 'MAINCC': '/usr/bin/ccache /opt/rh/devtoolset-2/root/usr/bin/gcc '
+           '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
+           '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
+           '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
+           '-pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/python-inst/share/man',
  'MKDIR_P': '/bin/mkdir -p',
  'MODLIBS': '',
- 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/_functoolsmodule.o  Modules/operator.o  Modules/_collectionsmodule.o  Modules/itertoolsmodule.o  Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o Modules/textio.o Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  Modules/symtablemodule.o  Modules/unicodedata.o  Modules/md5module.o  Modules/sha1module.o  Modules/sha256module.o  Modules/sha512module.o  Modules/xxsubtype.o',
+ 'MODNAMES': '_thread _signal posix errno pwd _sre _codecs _weakref _functools '
+             '_operator _collections itertools atexit _stat time _locale _io '
+             'zipimport faulthandler _tracemalloc _symtable xxsubtype',
+ 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  '
+            'Modules/posixmodule.o  Modules/errnomodule.o  '
+            'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
+            'Modules/_weakref.o  Modules/_functoolsmodule.o  '
+            'Modules/_operator.o  Modules/_collectionsmodule.o  '
+            'Modules/itertoolsmodule.o  Modules/atexitmodule.o  '
+            'Modules/_stat.o  Modules/timemodule.o  Modules/_localemodule.o  '
+            'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
+            'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
+            'Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  '
+            'Modules/_tracemalloc.o Modules/hashtable.o  '
+            'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
+ 'MULTIARCH': '',
  'MVWDELCH_IS_EXPRESSION': 0,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPCODETARGETGEN': '\\',
- 'OPCODETARGETGEN_FILES': '\\',
- 'OPCODETARGETS_H': '\\',
- 'OPT': '-DNDEBUG  -O0 -Wall -Wstrict-prototypes',
+ 'OPT': '-DNDEBUG -g  -O3 -Wall -Wstrict-prototypes',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -492,11 +573,16 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PGENOBJS': '\\ \\',
  'PGENSRCS': '\\ \\',
  'PGOBJS': '\\',
+ 'PGO_PROF_GEN_FLAG': '-fprofile-generate',
+ 'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
  'PGSRCS': '\\',
  'PLATDIR': 'plat-linux',
  'POBJS': '\\',
- 'POSIX_SEMAPHORES_NOT_ENABLED': 1,
- 'PROFILE_TASK': './Tools/pybench/pybench.py -n 2 --with-gc --with-syscheck',
+ 'POSIX_SEMAPHORES_NOT_ENABLED': 0,
+ 'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb '
+                 'test_multiprocessing_fork test_multiprocessing_forkserver '
+                 'test_multiprocessing_main_handling '
+                 'test_multiprocessing_spawn test_subprocess',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -509,28 +595,35 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': ':plat-linux',
  'PYTHON_FOR_BUILD': './python -E',
+ 'PYTHON_FOR_REGEN': 'python',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -DNDEBUG  -O0 -Wall -Wstrict-prototypes',
- 'PY_CORE_CFLAGS': '-fno-strict-aliasing -DNDEBUG  -O0 -Wall -Wstrict-prototypes -I. -I./Include -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 -Wall '
+              '-Wstrict-prototypes',
+ 'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 -Wall '
+                   '-Wstrict-prototypes -Werror=declaration-after-statement '
+                   '-I. -I./Include -fPIC -DPy_BUILD_CORE',
  'PY_CPPFLAGS': '-I. -I./Include',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/home/baseline/core/solver/unxlngi6.pro/lib -L/home/baseline/core/solver/unxlngi6.pro/lib',
+ 'PY_LDFLAGS': '-L/home/buildslave/build/workdir/UnpackedTarball/openssl '
+               '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
+ 'Py_HASH_ALGORITHM': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
  'RANLIB': 'ranlib',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/home/baseline/core/workdir/unxlngi6.pro/UnpackedTarball/python3:',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/home/buildslave/build/workdir/UnpackedTarball/python3',
  'SCRIPTDIR': '/python-inst/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lpthread -ldl  -lutil',
- 'SHLIB_EXT': '""',
+ 'SHLIBS': '-lpthread -ldl  -lutil -lrt',
+ 'SHLIB_SUFFIX': '.so',
  'SIGNAL_OBJS': '',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
@@ -551,34 +644,37 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SO': '.cpython-33m.so',
- 'SOABI': 'cpython-33m',
- 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
+ 'SOABI': 'cpython-3.5m',
+ 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
+ 'STRIPFLAG': '-s',
  'SUBDIRS': '',
  'SUBDIRSTOO': 'Include Lib Misc',
- 'SYSCONFIGDATA': './Lib/_sysconfigdata.py',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TANH_PRESERVES_ZERO_SIGN': 1,
+ 'TCLTK_INCLUDES': '',
+ 'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/baseline/core/workdir/unxlngi6.pro/UnpackedTarball/python3: ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/buildslave/build/workdir/UnpackedTarball/python3 '
+               './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/baseline/core/workdir/unxlngi6.pro/UnpackedTarball/python3: ./python ./Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/buildslave/build/workdir/UnpackedTarball/python3 '
+               './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 3600,
  'THREADOBJ': 'Python/thread.o',
  'TIMEMODULE_LIB': 'rt',
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
- 'UNICODE_DEPS': '\\ \\',
+ 'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'USE_COMPUTED_GOTOS': 0,
  'USE_INLINE': 1,
  'VA_LIST_IS_ARRAY': 0,
- 'VERSION': '3.3',
+ 'VERSION': '3.5',
  'WANT_SIGFPE_HANDLER': 0,
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DOC_STRINGS': 1,
@@ -591,6 +687,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
+ 'abs_builddir': '/home/buildslave/build/workdir/UnpackedTarball/python3',
+ 'abs_srcdir': '/home/buildslave/build/workdir/UnpackedTarball/python3',
  'datarootdir': '/python-inst/share',
  'exec_prefix': '/python-inst',
  'prefix': '/python-inst',
